#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys, locale
from PyQt4 import QtGui
from PyQt4 import QtCore
import graphe

#if __name__ == "__main__":
#    app = QtGui.QApplication(sys.argv)
#    global MainWindow
#    MainWindow = QtGui.QMainWindow()
#    ui = graphe.Ui_MainWindow()
#    ui.setupUi(MainWindow,app)
#    MainWindow.show()
##    MainWindow.showFullScreen()
#    sys.exit(app.exec_())  

if __name__ == "__main__":
    app = QtGui.QApplication (sys.argv)

    translator = QtCore.QTranslator(app)
    translator.load("/opt/rtap/locale/rtap_" + locale.getlocale()[0] + ".qm")
    app.installTranslator(translator)
    ui = graphe.Ui_MainWindow()
    ui.setupUi(app)
    ui.show()

    sys.exit (app.exec_ ())

